@@ -6,7 +6,6 @@ import hashlib
 import os
 import posixpath
 import re
-import sys
 from importlib import import_module
 from os import path
 from typing import IO, Any
@@ -17,6 +16,7 @@ from sphinx.locale import __
 from sphinx.util import display as _display
 from sphinx.util import exceptions as _exceptions
 from sphinx.util import http_date as _http_date
+from sphinx.util import index_entries as _index_entries
 from sphinx.util import logging
 from sphinx.util import osutil as _osutil
 from sphinx.util.console import strip_colors  # NoQA: F401
@@ -44,15 +44,14 @@ from sphinx.util.osutil import (  # noqa: F401
 logger = logging.getLogger(__name__)
 
 # Generally useful regular expressions.
-ws_re: re.Pattern = re.compile(r'\s+')
-url_re: re.Pattern = re.compile(r'(?P<schema>.+)://.*')
+ws_re: re.Pattern[str] = re.compile(r'\s+')
+url_re: re.Pattern[str] = re.compile(r'(?P<schema>.+)://.*')
 
 
 # High-level utility functions.
 
 def docname_join(basedocname: str, docname: str) -> str:
-    return posixpath.normpath(
-        posixpath.join('/' + basedocname, '..', docname))[1:]
+    return posixpath.normpath(posixpath.join('/' + basedocname, '..', docname))[1:]
 
 
 def get_filetype(source_suffix: dict[str, str], filename: str) -> str:
@@ -105,26 +104,20 @@ class FilenameUniqDict(dict):
         self._existing = state
 
 
-def md5(data=b'', **kwargs):
-    """Wrapper around hashlib.md5
+def _md5(data=b'', **_kw):
+    """Deprecated wrapper around hashlib.md5
 
-    Attempt call with 'usedforsecurity=False' if supported.
+    To be removed in Sphinx 9.0
     """
-
-    if sys.version_info[:2] > (3, 8):
-        return hashlib.md5(data, usedforsecurity=False)
-    return hashlib.md5(data, **kwargs)
+    return hashlib.md5(data, usedforsecurity=False)
 
 
-def sha1(data=b'', **kwargs):
-    """Wrapper around hashlib.sha1
+def _sha1(data=b'', **_kw):
+    """Deprecated wrapper around hashlib.sha1
 
-    Attempt call with 'usedforsecurity=False' if supported.
+    To be removed in Sphinx 9.0
     """
-
-    if sys.version_info[:2] > (3, 8):
-        return hashlib.sha1(data, usedforsecurity=False)
-    return hashlib.sha1(data, **kwargs)
+    return hashlib.sha1(data, usedforsecurity=False)
 
 
 class DownloadFiles(dict):
@@ -136,7 +129,7 @@ class DownloadFiles(dict):
 
     def add_file(self, docname: str, filename: str) -> str:
         if filename not in self:
-            digest = md5(filename.encode()).hexdigest()
+            digest = hashlib.md5(filename.encode(), usedforsecurity=False).hexdigest()
             dest = f'{digest}/{os.path.basename(filename)}'
             self[filename] = (set(), dest)
 
@@ -155,23 +148,6 @@ class DownloadFiles(dict):
                 self.add_file(docname, filename)
 
 
-def get_full_modname(modname: str, attribute: str) -> str | None:
-    if modname is None:
-        # Prevents a TypeError: if the last getattr() call will return None
-        # then it's better to return it directly
-        return None
-    module = import_module(modname)
-
-    # Allow an attribute to have multiple parts and incidentally allow
-    # repeated .s in the attribute.
-    value = module
-    for attr in attribute.split('.'):
-        if attr:
-            value = getattr(value, attr)
-
-    return getattr(value, '__module__', None)
-
-
 # a regex to recognize coding cookies
 _coding_re = re.compile(r'coding[:=]\s*([-\w.]+)')
 
@@ -238,39 +214,13 @@ def parselinenos(spec: str, total: int) -> list[int]:
                 items.extend(range(start - 1, end))
             else:
                 raise ValueError
-        except Exception as exc:
-            raise ValueError('invalid line number spec: %r' % spec) from exc
+        except ValueError as exc:
+            msg = f'invalid line number spec: {spec!r}'
+            raise ValueError(msg) from exc
 
     return items
 
 
-def split_into(n: int, type: str, value: str) -> list[str]:
-    """Split an index entry into a given number of parts at semicolons."""
-    parts = [x.strip() for x in value.split(';', n - 1)]
-    if sum(1 for part in parts if part) < n:
-        raise ValueError(f'invalid {type} index entry {value!r}')
-    return parts
-
-
-def split_index_msg(type: str, value: str) -> list[str]:
-    # new entry types must be listed in directives/other.py!
-    if type == 'single':
-        try:
-            result = split_into(2, 'single', value)
-        except ValueError:
-            result = split_into(1, 'single', value)
-    elif type == 'pair':
-        result = split_into(2, 'pair', value)
-    elif type == 'triple':
-        result = split_into(3, 'triple', value)
-    elif type in {'see', 'seealso'}:
-        result = split_into(2, 'see', value)
-    else:
-        raise ValueError(f'invalid {type} index entry {value!r}')
-
-    return result
-
-
 def import_object(objname: str, source: str | None = None) -> Any:
     """Import python object by qualname."""
     try:
@@ -292,36 +242,6 @@ def import_object(objname: str, source: str | None = None) -> Any:
         raise ExtensionError('Could not import %s' % objname, exc) from exc
 
 
-def split_full_qualified_name(name: str) -> tuple[str | None, str]:
-    """Split full qualified name to a pair of modname and qualname.
-
-    A qualname is an abbreviation for "Qualified name" introduced at PEP-3155
-    (https://peps.python.org/pep-3155/).  It is a dotted path name
-    from the module top-level.
-
-    A "full" qualified name means a string containing both module name and
-    qualified name.
-
-    .. note:: This function actually imports the module to check its existence.
-              Therefore you need to mock 3rd party modules if needed before
-              calling this function.
-    """
-    parts = name.split('.')
-    for i, _part in enumerate(parts, 1):
-        try:
-            modname = ".".join(parts[:i])
-            import_module(modname)
-        except ImportError:
-            if parts[:i - 1]:
-                return ".".join(parts[:i - 1]), ".".join(parts[i - 1:])
-            else:
-                return None, ".".join(parts)
-        except IndexError:
-            pass
-
-    return name, ""
-
-
 def encode_uri(uri: str) -> str:
     split = list(urlsplit(uri))
     split[1] = split[1].encode('idna').decode('ascii')
@@ -357,12 +277,18 @@ _DEPRECATED_OBJECTS = {
     'format_exception_cut_frames': (_exceptions.format_exception_cut_frames,
                                     'sphinx.exceptions.format_exception_cut_frames'),
     'xmlname_checker': (_xml_name_checker, 'sphinx.builders.epub3._XML_NAME_PATTERN'),
+    'split_index_msg': (_index_entries.split_index_msg,
+                        'sphinx.util.index_entries.split_index_msg'),
+    'split_into': (_index_entries.split_index_msg, 'sphinx.util.index_entries.split_into'),
+    'md5': (_md5, ''),
+    'sha1': (_sha1, ''),
 }
 
 
 def __getattr__(name):
     if name not in _DEPRECATED_OBJECTS:
-        raise AttributeError(f'module {__name__!r} has no attribute {name!r}')
+        msg = f'module {__name__!r} has no attribute {name!r}'
+        raise AttributeError(msg)
 
     from sphinx.deprecation import _deprecation_warning
 
