@@ -9,7 +9,6 @@ import textwrap
 import time
 import wsgiref.handlers
 from base64 import b64encode
-from datetime import datetime
 from os import path
 from queue import Queue
 from unittest import mock
@@ -152,6 +151,7 @@ def test_defaults(app):
     }
     # looking for '#top' and '#does-not-exist' not found should fail
     assert rowsby["http://localhost:7777/#top"]["info"] == "Anchor 'top' not found"
+    assert rowsby["http://localhost:7777/#top"]["status"] == "broken"
     assert rowsby["http://localhost:7777#does-not-exist"]["info"] == "Anchor 'does-not-exist' not found"
     # images should fail
     assert "Not Found for url: http://localhost:7777/image.png" in rowsby["http://localhost:7777/image.png"]["info"]
@@ -166,6 +166,22 @@ def test_defaults(app):
     }
 
 
+@pytest.mark.sphinx(
+    'linkcheck', testroot='linkcheck', freshenv=True,
+    confoverrides={'linkcheck_anchors': False})
+def test_check_link_response_only(app):
+    with http_server(DefaultsHandler):
+        app.build()
+
+    # JSON output
+    assert (app.outdir / 'output.json').exists()
+    content = (app.outdir / 'output.json').read_text(encoding='utf8')
+
+    rows = [json.loads(x) for x in content.splitlines()]
+    rowsby = {row["uri"]: row for row in rows}
+    assert rowsby["http://localhost:7777/#top"]["status"] == "working"
+
+
 @pytest.mark.sphinx('linkcheck', testroot='linkcheck-too-many-retries', freshenv=True)
 def test_too_many_retries(app):
     with http_server(DefaultsHandler):
@@ -569,13 +585,13 @@ class OKHandler(http.server.BaseHTTPRequestHandler):
         self.wfile.write(content)
 
 
+@mock.patch("sphinx.builders.linkcheck.requests.get", wraps=requests.get)
 @pytest.mark.sphinx('linkcheck', testroot='linkcheck-localserver-https', freshenv=True)
-def test_invalid_ssl(app):
+def test_invalid_ssl(get_request, app):
     # Link indicates SSL should be used (https) but the server does not handle it.
     with http_server(OKHandler):
-        with mock.patch("sphinx.builders.linkcheck.requests.get", wraps=requests.get) as get_request:
-            app.build()
-            assert not get_request.called
+        app.build()
+        assert not get_request.called
 
     with open(app.outdir / 'output.json', encoding='utf-8') as fp:
         content = json.load(fp)
@@ -758,8 +774,7 @@ def test_too_many_requests_retry_after_int_delay(app, capsys, status):
 
 @pytest.mark.sphinx('linkcheck', testroot='linkcheck-localserver', freshenv=True)
 def test_too_many_requests_retry_after_HTTP_date(app, capsys):
-    now = datetime.now().timetuple()
-    retry_after = wsgiref.handlers.format_date_time(time.mktime(now))
+    retry_after = wsgiref.handlers.format_date_time(time.time())
     with http_server(make_retry_after_handler([(429, retry_after), (200, None)])):
         app.build()
     content = (app.outdir / 'output.json').read_text(encoding='utf8')
@@ -782,7 +797,7 @@ def test_too_many_requests_retry_after_HTTP_date(app, capsys):
 
 @pytest.mark.sphinx('linkcheck', testroot='linkcheck-localserver', freshenv=True)
 def test_too_many_requests_retry_after_without_header(app, capsys):
-    with http_server(make_retry_after_handler([(429, None), (200, None)])),\
+    with http_server(make_retry_after_handler([(429, None), (200, None)])), \
          mock.patch("sphinx.builders.linkcheck.DEFAULT_DELAY", 0):
         app.build()
     content = (app.outdir / 'output.json').read_text(encoding='utf8')
