@@ -5,6 +5,7 @@ source file translated by test_build.
 """
 
 import sys
+from types import SimpleNamespace
 from unittest.mock import Mock
 from warnings import catch_warnings
 
@@ -14,7 +15,6 @@ from docutils.statemachine import ViewList
 from sphinx import addnodes
 from sphinx.ext.autodoc import ALL, ModuleLevelDocumenter, Options
 from sphinx.ext.autodoc.directive import DocumenterBridge, process_documenter_options
-from sphinx.testing.util import SphinxTestApp, Struct  # noqa: F401
 from sphinx.util.docutils import LoggingReporter
 
 try:
@@ -48,7 +48,7 @@ def make_directive_bridge(env):
         special_members = False,
         imported_members = False,
         show_inheritance = False,
-        noindex = False,
+        no_index = False,
         annotation = None,
         synopsis = '',
         platform = '',
@@ -59,7 +59,7 @@ def make_directive_bridge(env):
         ignore_module_all = False,
     )
 
-    directive = Struct(
+    directive = SimpleNamespace(
         env = env,
         genopt = options,
         result = ViewList(),
@@ -217,7 +217,7 @@ def test_format_signature(app):
     class ExceptionSubclass(Exception):
         pass
 
-    # Exception has no __text_signature__ at least in Python 3.8
+    # Exception has no __text_signature__ at least in Python 3.11
     if getattr(Exception, '__text_signature__', None) is None:
         assert formatsig('class', 'C', ExceptionSubclass, None, None) == ''
 
@@ -403,42 +403,40 @@ def test_new_documenter(app):
     ]
 
 
+@pytest.mark.sphinx('html', testroot='ext-autodoc')
 def test_attrgetter_using(app):
-    from target import Class
-    from target.inheritance import Derived
-
     directive = make_directive_bridge(app.env)
+    directive.genopt['members'] = ALL
 
-    def assert_getter_works(objtype, name, obj, attrs=[], **kw):
-        getattr_spy = []
-
-        def special_getattr(obj, name, *defargs):
-            if name in attrs:
-                getattr_spy.append((obj, name))
-                return None
-            return getattr(obj, name, *defargs)
-        app.add_autodoc_attrgetter(type, special_getattr)
-
-        del getattr_spy[:]
-        inst = app.registry.documenters[objtype](directive, name)
-        inst.generate(**kw)
-
-        hooked_members = [s[1] for s in getattr_spy]
-        documented_members = [s[1] for s in processed_signatures]
-        for attr in attrs:
-            fullname = '.'.join((name, attr))
-            assert attr in hooked_members
-            assert fullname not in documented_members, \
-                '%r was not hooked by special_attrgetter function' % fullname
-
+    directive.genopt['inherited_members'] = False
     with catch_warnings(record=True):
-        directive.genopt['members'] = ALL
-        directive.genopt['inherited_members'] = False
-        print(directive.genopt)
-        assert_getter_works('class', 'target.Class', Class, ['meth'])
+        _assert_getter_works(app, directive, 'class', 'target.Class', ['meth'])
 
-        directive.genopt['inherited_members'] = True
-        assert_getter_works('class', 'target.inheritance.Derived', Derived, ['inheritedmeth'])
+    directive.genopt['inherited_members'] = True
+    with catch_warnings(record=True):
+        _assert_getter_works(app, directive, 'class', 'target.inheritance.Derived', ['inheritedmeth'])
+
+
+def _assert_getter_works(app, directive, objtype, name, attrs=(), **kw):
+    getattr_spy = []
+
+    def _special_getattr(obj, attr_name, *defargs):
+        if attr_name in attrs:
+            getattr_spy.append((obj, attr_name))
+            return None
+        return getattr(obj, attr_name, *defargs)
+
+    app.add_autodoc_attrgetter(type, _special_getattr)
+
+    getattr_spy.clear()
+    app.registry.documenters[objtype](directive, name).generate(**kw)
+
+    hooked_members = {s[1] for s in getattr_spy}
+    documented_members = {s[1] for s in processed_signatures}
+    for attr in attrs:
+        fullname = '.'.join((name, attr))
+        assert attr in hooked_members
+        assert fullname not in documented_members, f'{fullname!r} not intercepted'
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
@@ -810,7 +808,7 @@ def test_autodoc_imported_members(app):
                "imported-members": None,
                "ignore-module-all": None}
     actual = do_autodoc(app, 'module', 'target', options)
-    assert '.. py:function:: function_to_be_imported(app: Sphinx | None) -> str' in actual
+    assert '.. py:function:: function_to_be_imported(app: ~sphinx.application.Sphinx | None) -> str' in actual
 
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
@@ -927,22 +925,22 @@ def test_autodoc_ignore_module_all(app):
 
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
 def test_autodoc_noindex(app):
-    options = {"noindex": None}
+    options = {"no-index": None}
     actual = do_autodoc(app, 'module', 'target', options)
     assert list(actual) == [
         '',
         '.. py:module:: target',
-        '   :noindex:',
+        '   :no-index:',
         '',
     ]
 
-    # TODO: :noindex: should be propagated to children of target item.
+    # TODO: :no-index: should be propagated to children of target item.
 
     actual = do_autodoc(app, 'class', 'target.inheritance.Base', options)
     assert list(actual) == [
         '',
         '.. py:class:: Base()',
-        '   :noindex:',
+        '   :no-index:',
         '   :module: target.inheritance',
         '',
     ]
@@ -1984,7 +1982,6 @@ def test_autodoc_TypeVar(app):
     ]
 
 
-@pytest.mark.skipif(sys.version_info[:2] <= (3, 8), reason='py39+ is required.')
 @pytest.mark.sphinx('html', testroot='ext-autodoc')
 def test_autodoc_Annotated(app):
     options = {"members": None}
@@ -2018,7 +2015,11 @@ def test_autodoc_TYPE_CHECKING(app):
         '',
         '   .. py:attribute:: Foo.attr1',
         '      :module: target.TYPE_CHECKING',
-        '      :type: StringIO',
+        '      :type: ~_io.StringIO',
+        '',
+        '',
+        '.. py:function:: spam(ham: ~collections.abc.Iterable[str]) -> tuple[~gettext.NullTranslations, bool]',
+        '   :module: target.TYPE_CHECKING',
         '',
     ]
 
@@ -2466,3 +2467,59 @@ def test_canonical(app):
         '      docstring',
         '',
     ]
+
+
+@pytest.mark.sphinx('html', testroot='ext-autodoc')
+def test_literal_render(app):
+    def bounded_typevar_rst(name, bound):
+        return [
+            '',
+            f'.. py:class:: {name}',
+            '   :module: target.literal',
+            '',
+            '   docstring',
+            '',
+            f'   alias of TypeVar({name!r}, bound={bound})',
+            '',
+        ]
+
+    def function_rst(name, sig):
+        return [
+            '',
+            f'.. py:function:: {name}({sig})',
+            '   :module: target.literal',
+            '',
+            '   docstring',
+            '',
+        ]
+
+    # autodoc_typehints_format can take 'short' or 'fully-qualified' values
+    # and this will be interpreted as 'smart' or 'fully-qualified-except-typing' by restify()
+    # and 'smart' or 'fully-qualified' by stringify_annotation().
+
+    options = {'members': None, 'exclude-members': 'MyEnum'}
+    app.config.autodoc_typehints_format = 'short'
+    actual = do_autodoc(app, 'module', 'target.literal', options)
+    assert list(actual) == [
+        '',
+        '.. py:module:: target.literal',
+        '',
+        *bounded_typevar_rst('T', r'\ :py:obj:`~typing.Literal`\ [1234]'),
+        *bounded_typevar_rst('U', r'\ :py:obj:`~typing.Literal`\ [:py:attr:`~target.literal.MyEnum.a`]'),
+        *function_rst('bar', 'x: ~typing.Literal[1234]'),
+        *function_rst('foo', 'x: ~typing.Literal[MyEnum.a]'),
+    ]
+
+    # restify() assumes that 'fully-qualified' is 'fully-qualified-except-typing'
+    # because it is more likely that a user wants to suppress 'typing.*'
+    app.config.autodoc_typehints_format = 'fully-qualified'
+    actual = do_autodoc(app, 'module', 'target.literal', options)
+    assert list(actual) == [
+        '',
+        '.. py:module:: target.literal',
+        '',
+        *bounded_typevar_rst('T', r'\ :py:obj:`~typing.Literal`\ [1234]'),
+        *bounded_typevar_rst('U', r'\ :py:obj:`~typing.Literal`\ [:py:attr:`target.literal.MyEnum.a`]'),
+        *function_rst('bar', 'x: typing.Literal[1234]'),
+        *function_rst('foo', 'x: typing.Literal[target.literal.MyEnum.a]'),
+    ]
